hray <-
function(x, y, val, lowbnd = NULL, highbnd = NULL,
         minval = if(is.null(lowbnd)) min(val) else min(lowbnd),
         maxval = if(is.null(highbnd)) max(val) else max(highbnd),
         raylength = 0.3, raylwd = 2, raypen = 1, dotlength = 0.06,
         dotsides = 8, dotlwd = 1, dotden = 0, dotborder = TRUE,
         dotpen = 1,
         ticlength = 0.06, ticsides = 8, ticlwd = 1, ticpen = 1,
         arclength = 0.75, arcsides = 18, arclwd = 1, arcden = NULL,
         arcborder = FALSE, arcpen = 2,
         minangle =  - pi/2, maxangle = pi/2, clockwise = FALSE)
{
    n <- length(x)
    ## Puin <- par("uin") :
    P <- par(c("pin", "usr"))
    Puin <- c(P$pin[1]/(P$usr[2]-P$usr[1]),
              P$pin[2]/(P$usr[4]-P$usr[3]))
    if(clockwise && maxangle > minangle)
        maxangle <- maxangle - 2 * pi
    angle.con <- (maxangle - minangle)/(maxval - minval)

    ## raylength, dotlength, ticlength == FALSE  ---> treated as 0 automatically

    if(length(raylength) == 1)
        raylength <- rep(raylength, length(val))
    ## __________________plot confidence arcs_________________________
    if(!is.null(lowbnd)) {
        if(is.null(highbnd))
            stop("Must also have upper confidence bound `highbnd'")
        if(length(arclength) == 1)
            arclength <- arclength * raylength
        arc.xunits <- arclength/Puin[1]
        arc.yunits <- arclength/Puin[2]
        arc <- seq(minangle, maxangle, length = arcsides)
        arc.cos <- cos(arc)
        arc.sin <- sin(arc)
        low.angle <- minangle + angle.con * (lowbnd - minval)
        low.angle.cos <- cos(low.angle)
        low.angle.sin <- sin(low.angle)
        high.angle <- minangle + angle.con * (highbnd - minval)
        high.angle.cos <- cos(high.angle)
        high.angle.sin <- sin(high.angle)
        for(i in 1:length(val)) {
            nx <- x[i]
            ny <- y[i]
            low <- low.angle[i]
            high <- high.angle[i]
            good <-
                if(clockwise)
                    high < arc & arc < low
                else low < arc & arc < high
            if(!any(good)) {
                nx <- c(nx, nx + arc.xunits[i] *
                        c(low.angle.cos[i], high.angle.cos[i]))
                ny <- c(ny, ny + arc.yunits[i] *
                        c(low.angle.sin[i], high.angle.sin[i]))
            }
            else {
                nx <- c(nx, nx + arc.xunits[i] *
                        c(low.angle.cos[i], arc.cos[good],
                          high.angle.cos[i]))
                ny <- c(ny, ny + arc.yunits[i] *
                        c(low.angle.sin[i], arc.sin[good],
                          high.angle.sin[i]))
            }
            polygon(nx, ny, border = arcborder, density = arcden,
                    col = arcpen, lwd = arclwd)

        }
    }
    ##____________________ plot tics_____________________________
    if(ticlength > 0) {
        tic.angle <- matrix((2 * pi * (1:ticsides - 1))/ticsides, ncol = 2)
        tic.angle <- as.vector(t(cbind(tic.angle,
                                       rep(NA, nrow(tic.angle)))))
        tic.n <- length(tic.angle)
        cray <- (ticlength * cos(tic.angle))/Puin[1]
        sray <- (ticlength * sin(tic.angle))/Puin[2]
        polyx <- rep(x, rep(tic.n, n)) + rep(cray, n)
        polyy <- rep(y, rep(tic.n, n)) + rep(sray, n)
        lines(polyx, polyy, lwd = ticlwd, col = ticpen)
    }
    ##___________________plot dots___________________________________
    if(dotlength > 0) {
        dot.angle <- (2 * pi * (1:dotsides - 1))/dotsides
        dot.cos <- c((dotlength * cos(dot.angle))/Puin[1], NA)
        dot.sin <- c((dotlength * sin(dot.angle))/Puin[2], NA)
        dot.n <- length(dot.cos)
        ##RG:dot.n, n)) + rep(dot.sin, n),
        polygon(rep(x, rep(dot.n, n)) + rep(dot.cos, n),
                rep(y, rep(dot.n, n)) + rep(dot.sin, n),
                border = dotborder, lwd = dotlwd, density = dotden)
    }
    ##_____________________plot rays______________________________
    if(raylength[1] > 0) {
        angle <- minangle + angle.con * (val - minval)
        ray.x <- raylength/Puin[1]
        ray.y <- raylength/Puin[2]
        segments(x, y,
                 x + ray.x * cos(angle),
                 y + ray.y * sin(angle), lwd = raylwd, col = raypen)
    }
}## hray()

